@@ -13,6 +13,8 @@ import logging
 import os, re, HTMLParser, base64, glob
 import urllib
 
+LOGGER = logging.getLogger(__name__)
+
 # Check for presence of set to be compatible with python 2.3
 try:
     set
@@ -22,7 +24,7 @@ except NameError:
 
 # Whether we will index firefox or mozilla bookmarks
 USING_FIREFOX = False
-if is_preferred_browser("firefox"):
+if is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
     USING_FIREFOX = True
         
 # File returned here should be checked for existence
@@ -149,16 +151,13 @@ class MozillaBookmarksHandler(deskbar.interfaces.Module):
     def query(self, query):
         # First, check the smart bookmarks, or "keywords", where
         # "wp Foo" takes you to the wikipedia entry for Foo.
-        x = self.query_smart_bookmarks(query, deskbar.DEFAULT_RESULTS_PER_HANDLER)
-        if x != None:
-            self.set_priority_for_matches( x )
-            self._emit_query_ready(query, x )
-        else:
+        matches = self.query_smart_bookmarks(query, deskbar.DEFAULT_RESULTS_PER_HANDLER)
+        if matches == None:
             # If none of the smart bookmarks matched as a prefix,
             # then we'll just look up all bookmarks.
             matches = self._bookmarks.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
-            self.set_priority_for_matches( matches )
-            self._emit_query_ready(query, matches )
+        self.set_priority_for_matches( matches )
+        self._emit_query_ready(query, matches )
     
     def query_smart_bookmarks(self, query, max):
         # if one of the smart bookmarks' shortcuts matches as a prefix,
@@ -169,7 +168,7 @@ class MozillaBookmarksHandler(deskbar.interfaces.Module):
             try:
                 b = self._shortcuts_to_smart_bookmarks_map[prefix]
                 text = query[x+1:]
-                return [BrowserSmartMatch(b.name, b.url, prefix, b, icon=b.icon)]
+                return [BrowserSmartMatch(b.get_name(), b.url, prefix, b, pixbuf=b.get_icon())]
             except KeyError:
                 # Probably from the b = ... line.  Getting here
                 # means that there is no such shortcut.
@@ -208,7 +207,8 @@ class MozillaSearchHandler(deskbar.interfaces.Module):
                 expanduser("~/.mozilla/searchplugins"),
                 "/usr/local/lib/firefox/searchplugins",
                 "/usr/lib/mozilla-firefox/searchplugins",
-                "/usr/local/lib/mozilla-firefox/searchplugins"] + \
+                "/usr/local/lib/mozilla-firefox/searchplugins",
+                "/usr/lib/iceweasel/searchplugins"] + \
                 glob.glob("/usr/lib*/firefox*/searchplugins")
         else:
             smart_dirs = [
@@ -225,8 +225,8 @@ class MozillaSearchHandler(deskbar.interfaces.Module):
         self._parse_search_engines(smart_dirs)
         
     def _parse_search_engines(self, smart_dirs):
-        self._smart_bookmarks = MozillaSmartBookmarksDirParser(self, smart_dirs).get_smart_bookmarks()
-        self.set_priority_for_matches( self._smart_bookmarks )
+        self._smart_bookmarks = MozillaSmartBookmarksDirParser(smart_dirs).get_smart_bookmarks()
+        self.set_priority_for_matches(self._smart_bookmarks)
 
     def stop(self):
         self.watcher.remove_all()
@@ -249,7 +249,7 @@ class MozillaSearchHandler(deskbar.interfaces.Module):
     
     @staticmethod
     def has_requirements():
-        if is_preferred_browser("firefox"):
+        if is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             MozillaSearchHandler.INSTRUCTIONS = _("You can customize which search engines are offered.")
             return True
         elif is_preferred_browser("mozilla"):
@@ -280,7 +280,7 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.indexed_file = self._index_mozilla()
             self.close()
         except Exception, e:
-            logging.error('Could not index Firefox bookmarks: %s' % e)
+            LOGGER.error('Could not index Firefox bookmarks: %s' % e)
         
     def get_indexer(self):
         """
@@ -298,7 +298,7 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.feed(file(bookmarks_file).read())
                 return bookmarks_file
         except Exception, msg:
-            logging.error('Retrieving Mozilla Bookmarks: %s' % msg)
+            LOGGER.error('Retrieving Mozilla Bookmarks: %s' % msg)
         
     def _index_firefox(self):
         try:
@@ -307,7 +307,7 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.feed(file(bookmarks_file).read())
                 return bookmarks_file
         except Exception, msg:
-            logging.error('Retrieving Firefox Bookmarks: %s' % msg)
+            LOGGER.error('Retrieving Firefox Bookmarks: %s' % msg)
     
     def handle_starttag(self, tag, attrs):
         tag = tag.lower()
@@ -387,7 +387,7 @@ class Firefox2SearchEngineParser :
         try:
             self._parse_image (xml)
         except Exception, msg:
-            logging.error("Parsing icon for %s\n%s" % (self.filename,msg))
+            LOGGER.error("Parsing icon for %s\n%s" % (self.filename,msg))
     
     def _detect_namespace (self, xml):
         # Manually added search engines use the "os" namespace
@@ -549,7 +549,7 @@ class MozillaSmartBookmarksParser:
             parent_dir = self.f[:self.f.rindex("/")]
             return [img for img in glob.glob(join(parent_dir, '%s.*' % self.f[:-4])) if not img.endswith(".src")][0]
         except Exception, msg:
-            logging.warning("Error detecting icon for smart bookmark:%s\n%s" % (self.f,msg))
+            LOGGER.warning("Error detecting icon for smart bookmark:%s\n%s" % (self.f,msg))
             return None
     
     def _handle_token(self, state, tokens):
@@ -668,7 +668,7 @@ class Tokenizer:
             return token
             
 class MozillaSmartBookmarksDirParser:
-    def __init__(self, handler, dirs):
+    def __init__(self, dirs):
         self._smart_bookmarks = []
         
         # Avoid getting duplicate search engines
@@ -694,7 +694,7 @@ class MozillaSmartBookmarksDirParser:
                 if not basename(f) in bookmark_names:
                     found_bookmarks.append(f)
                     bookmark_names.append(basename(f))
-        
+      
         for f in found_bookmarks:
             img = None
             if f.endswith (".xml"):
@@ -721,7 +721,7 @@ class MozillaSmartBookmarksDirParser:
                 self._smart_bookmarks.append(bookmark)
                 
             except Exception, msg:
-                logging.error('MozillaSmartBookmarksDirParser:cannot parse smart bookmark: %s\n%s' % (f,msg))
+                LOGGER.error('MozillaSmartBookmarksDirParser:cannot parse smart bookmark: %s\n%s' % (f,msg))
                     
     
     def get_smart_bookmarks(self):
